@@ -13,7 +13,10 @@ class Team(BaseModel):
 
 
 class TeamsRoom(HealthRoom):
-    mode = RoomMode.teams
+    @staticmethod
+    def get_mode() -> RoomMode:
+        return RoomMode.teams
+
     team_size: int = 2
     teams: dict[str, Team] = {
         'red': Team(color=Color('red')),
